@@ -74,6 +74,7 @@ INSTALLED_APPS = [
 
 #: Default Django Middlewares.
 MIDDLEWARE = (
+    'allauth.account.middleware.AccountMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
@@ -208,11 +209,6 @@ STATICFILES_FINDERS = (
     'compressor.finders.CompressorFinder',
 )
 
-#: Django 1.6+ defaults to a JSON serializer, but it won't work with
-#: django-openid, see
-#: https://bugs.launchpad.net/django-openid-auth/+bug/1252826
-SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'
-
 
 #: Default Django URL to redirect to for Login.
 LOGIN_URL = 'account_login'
